@@ -1,6 +1,5 @@
 //! Types for returning SQL type information about queries.
 
-use crate::types::HasTypeMetadata;
 use crate::Database;
 use std::fmt::{self, Debug};
 
@@ -11,7 +10,7 @@ where
     DB: Database + ?Sized,
 {
     /// The expected types for the parameters of the query.
-    pub param_types: Box<[<DB as HasTypeMetadata>::TypeId]>,
+    pub param_types: Box<[DB::TypeInfo]>,
 
     /// The type and table information, if any for the results of the query.
     pub result_columns: Box<[Column<DB>]>,
@@ -20,7 +19,7 @@ where
 impl<DB> Debug for Describe<DB>
 where
     DB: Database,
-    <DB as HasTypeMetadata>::TypeId: Debug,
+    DB::TypeInfo: Debug,
     Column<DB>: Debug,
 {
     fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
@@ -38,21 +37,21 @@ where
     DB: Database + ?Sized,
 {
     pub name: Option<Box<str>>,
-    pub table_id: Option<<DB as HasTypeMetadata>::TableId>,
-    pub type_id: <DB as HasTypeMetadata>::TypeId,
+    pub table_id: Option<DB::TableId>,
+    pub type_info: DB::TypeInfo,
 }
 
 impl<DB> Debug for Column<DB>
 where
     DB: Database + ?Sized,
-    <DB as HasTypeMetadata>::TableId: Debug,
-    <DB as HasTypeMetadata>::TypeId: Debug,
+    DB::TableId: Debug,
+    DB::TypeInfo: Debug,
 {
     fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
         f.debug_struct("Column")
             .field("name", &self.name)
             .field("table_id", &self.table_id)
-            .field("type_id", &self.type_id)
+            .field("type_id", &self.type_info)
             .finish()
     }
 }
