@@ -9,6 +9,8 @@ impl Database for MySql {
     type Arguments = super::MySqlArguments;
 
     type Row = super::MySqlRow;
-}
 
-impl_into_arguments_for_database!(MySql);
+    type TypeInfo = super::MySqlTypeInfo;
+
+    type TableId = Box<str>;
+}
