@@ -1,10 +1,13 @@
 //! Low level Postgres protocol. Defines the encoding and decoding of the messages communicated
 //! to and from the database server.
 
-// There is much to the Postgres protocol that is not yet used. As we mature we'll be trimming
-// the size of this module to exactly what is necessary.
-#![allow(unused)]
+mod type_format;
+mod type_id;
 
+pub use type_format::TypeFormat;
+pub use type_id::TypeId;
+
+// REQUESTS
 mod bind;
 mod cancel_request;
 mod close;
@@ -16,6 +19,7 @@ mod parse;
 mod password_message;
 mod query;
 mod sasl;
+mod ssl_request;
 mod startup_message;
 mod statement;
 mod sync;
@@ -32,11 +36,13 @@ pub use parse::Parse;
 pub use password_message::PasswordMessage;
 pub use query::Query;
 pub use sasl::{hi, SaslInitialResponse, SaslResponse};
+pub use ssl_request::SslRequest;
 pub use startup_message::StartupMessage;
 pub use statement::StatementId;
 pub use sync::Sync;
 pub use terminate::Terminate;
 
+// RESPONSES
 mod authentication;
 mod backend_key_data;
 mod command_complete;
